#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Script to convert a web2py translation dictionary into a PO file
# uses: Translate Toolkit <http://translate.sourceforge.net>
#
# options:
#   -i [inputfile]  (use '-' for stdin)
#   -o [outputfile] (optional, defaults to stdout)
#
# (c) 2009 Dominic König (dominic@nursix.org)
#
# This program is subject to the GNU General Public License Version 2 or later
#
"""convert web2py translation dictionaries (.py) to GNU/gettext PO files"""

import sys
from translate.storage import po

class web2py2po:
    def __init__(self, pofile=None):
        self.mypofile = pofile

    def convertunit(self, source_str, target_str):
        pounit = po.pounit(encoding="UTF-8")
        pounit.setsource( source_str )
        if target_str:
            pounit.settarget( target_str )
        return pounit

    def convertstore(self, mydict):

        targetheader = self.mypofile.makeheader(charset="UTF-8", encoding="8bit")
        targetheader.addnote("extracted from web2py", "developer")

        self.mypofile.addunit(targetheader)

        for source_str in mydict.keys():
            target_str = mydict[source_str]
            if target_str.startswith('*** '):
                target_str = ''
            pounit = self.convertunit(source_str, target_str)
            self.mypofile.addunit(pounit)

        return self.mypofile

def convertpy(inputfile, outputfile, encoding="UTF-8"):

    new_pofile = po.pofile()
    convertor = web2py2po(new_pofile)

    mydict = eval(inputfile.read())
    if not isinstance(mydict, dict):
        return 0

    outputstore = convertor.convertstore(mydict)

    if outputstore.isempty():
        return 0

    outputfile.write(str(outputstore))
    return 1

def main(argv=None):
    from translate.convert import convert
    formats = {("py", "po"): ("po", convertpy), ("py", None): ("po", convertpy)}
    parser = convert.ConvertOptionParser(formats, usetemplates=False, description=__doc__)
    parser.run(argv)

if __name__ == '__main__':
    main()
